@@ -118,21 +118,21 @@ SPK file and learn about the segments it offers:
 >>> kernel = SPK.open('de421.bsp')
 >>> print(kernel)
 File type DAF/SPK and format LTL-IEEE with 15 segments:
-2414864.50..2471184.50  Type 2  Solar System Barycenter (0) -> Mercury Barycenter (1)
-2414864.50..2471184.50  Type 2  Solar System Barycenter (0) -> Venus Barycenter (2)
-2414864.50..2471184.50  Type 2  Solar System Barycenter (0) -> Earth Barycenter (3)
-2414864.50..2471184.50  Type 2  Solar System Barycenter (0) -> Mars Barycenter (4)
-2414864.50..2471184.50  Type 2  Solar System Barycenter (0) -> Jupiter Barycenter (5)
-2414864.50..2471184.50  Type 2  Solar System Barycenter (0) -> Saturn Barycenter (6)
-2414864.50..2471184.50  Type 2  Solar System Barycenter (0) -> Uranus Barycenter (7)
-2414864.50..2471184.50  Type 2  Solar System Barycenter (0) -> Neptune Barycenter (8)
-2414864.50..2471184.50  Type 2  Solar System Barycenter (0) -> Pluto Barycenter (9)
-2414864.50..2471184.50  Type 2  Solar System Barycenter (0) -> Sun (10)
-2414864.50..2471184.50  Type 2  Earth Barycenter (3) -> Moon (301)
-2414864.50..2471184.50  Type 2  Earth Barycenter (3) -> Earth (399)
-2414864.50..2471184.50  Type 2  Mercury Barycenter (1) -> Mercury (199)
-2414864.50..2471184.50  Type 2  Venus Barycenter (2) -> Venus (299)
-2414864.50..2471184.50  Type 2  Mars Barycenter (4) -> Mars (499)
+1899-07-29..2053-10-09  Type 2  Solar System Barycenter (0) -> Mercury Barycenter (1)
+1899-07-29..2053-10-09  Type 2  Solar System Barycenter (0) -> Venus Barycenter (2)
+1899-07-29..2053-10-09  Type 2  Solar System Barycenter (0) -> Earth Barycenter (3)
+1899-07-29..2053-10-09  Type 2  Solar System Barycenter (0) -> Mars Barycenter (4)
+1899-07-29..2053-10-09  Type 2  Solar System Barycenter (0) -> Jupiter Barycenter (5)
+1899-07-29..2053-10-09  Type 2  Solar System Barycenter (0) -> Saturn Barycenter (6)
+1899-07-29..2053-10-09  Type 2  Solar System Barycenter (0) -> Uranus Barycenter (7)
+1899-07-29..2053-10-09  Type 2  Solar System Barycenter (0) -> Neptune Barycenter (8)
+1899-07-29..2053-10-09  Type 2  Solar System Barycenter (0) -> Pluto Barycenter (9)
+1899-07-29..2053-10-09  Type 2  Solar System Barycenter (0) -> Sun (10)
+1899-07-29..2053-10-09  Type 2  Earth Barycenter (3) -> Moon (301)
+1899-07-29..2053-10-09  Type 2  Earth Barycenter (3) -> Earth (399)
+1899-07-29..2053-10-09  Type 2  Mercury Barycenter (1) -> Mercury (199)
+1899-07-29..2053-10-09  Type 2  Venus Barycenter (2) -> Venus (299)
+1899-07-29..2053-10-09  Type 2  Mars Barycenter (4) -> Mars (499)
 
 Since the next few examples involve vector output, let’s tell NumPy to
 make vector output attractive.
@@ -140,18 +140,25 @@ make vector output attractive.
 >>> import numpy as np
 >>> np.set_printoptions(precision=3)
 
-Each segment of the file lets you predict the position of an object with
-respect to some other reference point.  If you want the coordinates of
-Mars at 2457061.5 (2015 February 8) with respect to the center of the
-solar system, this ephemeris only requires you to take a single step:
+Each segment of the file lets you predict the position of one body with
+respect to another for a given Julian date.  A small routine is provided
+to convert Gregorian calendar dates to Julian dates:
+
+>>> from jplephem.calendar import compute_julian_date
+>>> compute_julian_date(2015, 2, 8)
+2457061.5
+
+Here is how to compute the coordinates of Mars (target 4) relative to
+the Solar System barycenter (target 0) at midnight 2015 February 8 TDB
+(Barycentric Dynamical Time), using the Julian date we just computed:
 
 >>> position = kernel[0,4].compute(2457061.5)
 >>> print(position)
 [2.057e+08 4.251e+07 1.394e+07]
 
-But learning the position of Mars with respect to the Earth takes three
-steps, from Mars to the Solar System barycenter to the Earth-Moon
-barycenter and finally to Earth itself:
+By contrast, it takes three steps to learn the position of Mars with
+respect to the Earth: from Mars to the Solar System barycenter, to the
+Earth-Moon barycenter (3), and finally to Earth itself (399).
 
 >>> position = kernel[0,4].compute(2457061.5)
 >>> position -= kernel[0,3].compute(2457061.5)
@@ -159,9 +166,9 @@ barycenter and finally to Earth itself:
 >>> print(position)
 [ 3.161e+08 -4.679e+07 -2.476e+07]
 
-You can see that the output of this ephemeris is in kilometers.  If you
-use another ephemeris, check its documentation to be sure of the units
-that it employs.
+You can see that the output of this ephemeris DE421 is in kilometers.
+If you use another ephemeris, check its documentation to be sure of the
+units that it employs.
 
 If you supply the date as a NumPy array, then each component that is
 returned will itself be a vector as long as your date:
@@ -223,7 +230,7 @@ provided above and read through the code to learn more.
 
   >>> segment = kernel[3,399]
   >>> print(segment.describe())
-  2414864.50..2471184.50  Type 2  Earth Barycenter (3) -> Earth (399)
+  1899-07-29..2053-10-09  Type 2  Earth Barycenter (3) -> Earth (399)
     frame=1 source=DE-0421LE-0421
 
 * Each ``Segment`` loaded from the kernel has a number of attributes
@@ -330,6 +337,15 @@ You can ask for velocity as well.
 >>> print(v)
 [6.707e-09 4.838e-10 2.655e-06]
 
+Closing an ephemeris
+--------------------
+
+To release all open files and memory maps associated with an ephemeris,
+call its ``close()`` method.
+
+>>> kernel.close()
+>>> p.close()
+
 Reporting issues
 ----------------
 
@@ -340,6 +356,47 @@ https://github.com/brandon-rhodes/python-jplephem/
 Changelog
 ---------
 
+**2024 April 24 — Version 2.22**
+
+* When printed, segments now print their start and end dates using the
+  Gregorian calendar instead of printing raw Julian dates.
+
+* A small ``compute_julian_date`` routine is now provided for converting
+  calendar dates into Julian dates.
+
+* Fixed the text of the ``ValueError`` that is raised when the PCK
+  segment ``compute()`` method is given an out-of-range date; it was
+  reporting incorrectly large numbers for the Julian date range, because
+  a PCK counts time using seconds before or after J2000, not years.
+
+**2023 December 1 — Version 2.21**
+
+* Tweaked an import to avoid a fatal exception under Python 2, in case
+  anyone is still using it.
+
+**2023 November 13 — Version 2.20**
+
+* Each segment is now protected by a lock, in case two threads
+  simultaneously trigger the code that performs the initial load of the
+  segment’s data; the symptom was a rare exception ``ValueError: cannot
+  reshape array``.
+
+**2023 September 6 — Version 2.19**
+
+* Fixed a bug in the ``excerpt`` command that was causing it to truncate
+  its output when the input ephemeris had more than about two dozen
+  segments.  The command’s output should now include all matching
+  segments from even a very large ephemeris.
+
+* Fixed the ``excerpt`` command so the calendar dates specified on the
+  command line produce Julian dates ending with the fraction ``.5``,
+  which makes excerpt endpoints more exact.
+
+**2022 September 28 — Version 2.18**
+
+* Added support for big-endian processors, and created a GitHub Actions
+  CI build that includes both a big- and a little-endian architecture.
+
 **2021 December 31 — Version 2.17**
 
 * Fixed an ``AttributeError`` in the ``excerpt`` command.
@@ -487,15 +544,11 @@ The Jet Propulsion Laboratory's “Solar System Dynamics” page introduces
 the various options for doing solar system position computations:
 http://ssd.jpl.nasa.gov/?ephemerides
 
-The plain ASCII format element sets from which the ``jplephem`` Python
-ephemeris packages are built, along with documentation, can be found at:
-ftp://ssd.jpl.nasa.gov/pub/eph/planets/ascii/
-
 Equivalent FORTRAN code for using the ephemerides be found at the same
 FTP site: ftp://ssd.jpl.nasa.gov/pub/eph/planets/fortran/
 
 """
 from .ephem import Ephemeris, DateError
-__version__ = '2.17'
+__version__ = '2.22'
 
 __all__ = ['Ephemeris', 'DateError', '__version__']
